@@ -4,13 +4,18 @@ use strict;
 use warnings;
 use Carp;
 
+use Acme::HTTP;
+
+set_timeout(10);
+set_redir_max(5);
+
 require Exporter;
 
 our @ISA         = qw(Exporter);
 our %EXPORT_TAGS = ( all => [ qw(slurp_xml) ] );
 our @EXPORT_OK   = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT      = qw();
-our $VERSION     = '0.60';
+our $VERSION     = '0.61';
 
 my $use_module;
 
@@ -139,12 +144,6 @@ sub new {
     }
     else {
         if ($_[0] =~ m{\A https?:}xms) {
-            require Acme::HTTP;
-            Acme::HTTP->import(qw(:all));
-
-            set_timeout(10);
-            set_redir_max(5);
-
             $fh = Acme::HTTP->new($_[0])
               or croak "Failed assertion #0042 in XML::Reader->new: Can't Acme::HTTP->new('$_[0]') because $@";
         }
@@ -1001,7 +1000,7 @@ sub slurp_xml {
 
 package XML::Reader::Token;
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 sub found_start_tag   { $_[0][0] eq '<'; }
 sub found_end_tag     { $_[0][0] eq '>'; }
